
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '35.1.1',
    'branch_nick': 'release-35-LTS',
    'revision_id': '018b82c198120381bb9ba2966f1b8524c4f50094',
    'revno': 13115
}
